Readers
=======

.. automodule:: stonesoup.reader
    :no-members:

.. automodule:: stonesoup.reader.base
    :show-inheritance:

.. automodule:: stonesoup.reader.file
    :show-inheritance:

Generic
-------
.. automodule:: stonesoup.reader.generic
    :show-inheritance:

YAML
----
.. automodule:: stonesoup.reader.yaml
    :show-inheritance:

AISHub
------
.. automodule:: stonesoup.reader.aishub
    :show-inheritance:
